/* THEME ::: Genus Lavandula */

h1.content-header, h2.content-header, h3.content-header, h4.content-header {
    background-color: #debce1;
    border-color: #8653af;
    color: #a176c6 !important;
}

ul.table-of-content-list {
    background-color: #debce1;
    border-color: #8653af;
}

ul.table-of-content-list li {
    color: #a176c6 !important;
}

ul.table-of-content-list a {
    color: #a176c6 !important;
}

ul.table-of-content-list a:hover {
    color: #8653af !important;
}

div.markdown-container {
    background-color: #debce1;
    border-color: #8653af;
    color: #a176c6 !important;
}

div.markdown-container h1, div.markdown-container h2, div.markdown-container h3, div.markdown-container h4 {
    color: #a176c6 !important;
}
